@@ -24,6 +24,7 @@ from typing import IO, Callable, Deque, List, Optional, Sequence
 
 from opentelemetry.context import attach, detach, set_value
 from opentelemetry.sdk._logs import LogData, LogProcessor, LogRecord
+from opentelemetry.util._once import Once
 from opentelemetry.util._time import _time_ns
 
 _logger = logging.getLogger(__name__)
@@ -129,6 +130,9 @@ class _FlushRequest:
         self.num_log_records = 0
 
 
+_BSP_RESET_ONCE = Once()
+
+
 class BatchLogProcessor(LogProcessor):
     """This is an implementation of LogProcessor which creates batches of
     received logs in the export-friendly LogData representation and
@@ -147,7 +151,11 @@ class BatchLogProcessor(LogProcessor):
         self._max_export_batch_size = max_export_batch_size
         self._export_timeout_millis = export_timeout_millis
         self._queue = collections.deque()  # type: Deque[LogData]
-        self._worker_thread = threading.Thread(target=self.worker, daemon=True)
+        self._worker_thread = threading.Thread(
+            name="OtelBatchLogProcessor",
+            target=self.worker,
+            daemon=True,
+        )
         self._condition = threading.Condition(threading.Lock())
         self._shutdown = False
         self._flush_request = None  # type: Optional[_FlushRequest]
@@ -160,12 +168,18 @@ class BatchLogProcessor(LogProcessor):
             os.register_at_fork(
                 after_in_child=self._at_fork_reinit
             )  # pylint: disable=protected-access
+        self._pid = os.getpid()
 
     def _at_fork_reinit(self):
         self._condition = threading.Condition(threading.Lock())
         self._queue.clear()
-        self._worker_thread = threading.Thread(target=self.worker, daemon=True)
+        self._worker_thread = threading.Thread(
+            name="OtelBatchLogProcessor",
+            target=self.worker,
+            daemon=True,
+        )
         self._worker_thread.start()
+        self._pid = os.getpid()
 
     def worker(self):
         timeout = self._schedule_delay_millis / 1e3
@@ -178,7 +192,7 @@ class BatchLogProcessor(LogProcessor):
                 flush_request = self._get_and_unset_flush_request()
                 if (
                     len(self._queue) < self._max_export_batch_size
-                    and self._flush_request is None
+                    and flush_request is None
                 ):
                     self._condition.wait(timeout)
 
@@ -285,6 +299,9 @@ class BatchLogProcessor(LogProcessor):
         """
         if self._shutdown:
             return
+        if self._pid != os.getpid():
+            _BSP_RESET_ONCE.do_once(self._at_fork_reinit)
+
         self._queue.appendleft(log_data)
         if len(self._queue) >= self._max_export_batch_size:
             with self._condition:
