@@ -14,34 +14,47 @@
 
 
 from logging import WARNING
+from time import sleep
+from typing import Iterable, Sequence
 from unittest import TestCase
 from unittest.mock import MagicMock, Mock, patch
 
-from opentelemetry._metrics import NoOpMeter
-from opentelemetry.sdk._metrics import Meter, MeterProvider
-from opentelemetry.sdk._metrics.export import PeriodicExportingMetricReader
-from opentelemetry.sdk._metrics.instrument import (
+from opentelemetry.metrics import NoOpMeter
+from opentelemetry.sdk.metrics import (
     Counter,
     Histogram,
+    Meter,
+    MeterProvider,
     ObservableCounter,
     ObservableGauge,
     ObservableUpDownCounter,
     UpDownCounter,
 )
-from opentelemetry.sdk._metrics.metric_reader import MetricReader
-from opentelemetry.sdk._metrics.point import AggregationTemporality
+from opentelemetry.sdk.metrics.export import (
+    Metric,
+    MetricExporter,
+    MetricExportResult,
+    MetricReader,
+    PeriodicExportingMetricReader,
+)
+from opentelemetry.sdk.metrics.view import SumAggregation, View
 from opentelemetry.sdk.resources import Resource
 from opentelemetry.test.concurrency_test import ConcurrencyTestBase, MockFunc
 
 
 class DummyMetricReader(MetricReader):
     def __init__(self):
-        super().__init__(AggregationTemporality.CUMULATIVE)
+        super().__init__()
 
-    def _receive_metrics(self, metrics):
+    def _receive_metrics(
+        self,
+        metrics: Iterable[Metric],
+        timeout_millis: float = 10_000,
+        **kwargs,
+    ) -> None:
         pass
 
-    def shutdown(self):
+    def shutdown(self, timeout_millis: float = 30_000, **kwargs) -> None:
         return True
 
 
@@ -51,9 +64,11 @@ class TestMeterProvider(ConcurrencyTestBase):
         MeterProvider._all_metric_readers = set()
 
     def test_register_metric_readers(self):
-
-        metric_reader_0 = PeriodicExportingMetricReader(Mock())
-        metric_reader_1 = PeriodicExportingMetricReader(Mock())
+        mock_exporter = Mock()
+        mock_exporter._preferred_temporality = None
+        mock_exporter._preferred_aggregation = None
+        metric_reader_0 = PeriodicExportingMetricReader(mock_exporter)
+        metric_reader_1 = PeriodicExportingMetricReader(mock_exporter)
 
         try:
             MeterProvider(metric_readers=(metric_reader_0,))
@@ -208,7 +223,7 @@ class TestMeterProvider(ConcurrencyTestBase):
         with self.assertLogs(level=WARNING):
             meter_provider.shutdown()
 
-    @patch("opentelemetry.sdk._metrics._logger")
+    @patch("opentelemetry.sdk.metrics._internal._logger")
     def test_shutdown_race(self, mock_logger):
         mock_logger.warning = MockFunc()
         meter_provider = MeterProvider()
@@ -218,7 +233,9 @@ class TestMeterProvider(ConcurrencyTestBase):
         )
         self.assertEqual(mock_logger.warning.call_count, num_threads - 1)
 
-    @patch("opentelemetry.sdk._metrics.SynchronousMeasurementConsumer")
+    @patch(
+        "opentelemetry.sdk.metrics._internal." "SynchronousMeasurementConsumer"
+    )
     def test_measurement_collect_callback(
         self, mock_sync_measurement_consumer
     ):
@@ -239,14 +256,18 @@ class TestMeterProvider(ConcurrencyTestBase):
             sync_consumer_instance.collect.call_count, len(metric_readers)
         )
 
-    @patch("opentelemetry.sdk._metrics.SynchronousMeasurementConsumer")
+    @patch(
+        "opentelemetry.sdk.metrics." "_internal.SynchronousMeasurementConsumer"
+    )
     def test_creates_sync_measurement_consumer(
         self, mock_sync_measurement_consumer
     ):
         MeterProvider()
         mock_sync_measurement_consumer.assert_called()
 
-    @patch("opentelemetry.sdk._metrics.SynchronousMeasurementConsumer")
+    @patch(
+        "opentelemetry.sdk.metrics." "_internal.SynchronousMeasurementConsumer"
+    )
     def test_register_asynchronous_instrument(
         self, mock_sync_measurement_consumer
     ):
@@ -269,7 +290,9 @@ class TestMeterProvider(ConcurrencyTestBase):
             )
         )
 
-    @patch("opentelemetry.sdk._metrics.SynchronousMeasurementConsumer")
+    @patch(
+        "opentelemetry.sdk.metrics._internal." "SynchronousMeasurementConsumer"
+    )
     def test_consume_measurement_counter(self, mock_sync_measurement_consumer):
         sync_consumer_instance = mock_sync_measurement_consumer()
         meter_provider = MeterProvider()
@@ -279,7 +302,9 @@ class TestMeterProvider(ConcurrencyTestBase):
 
         sync_consumer_instance.consume_measurement.assert_called()
 
-    @patch("opentelemetry.sdk._metrics.SynchronousMeasurementConsumer")
+    @patch(
+        "opentelemetry.sdk.metrics." "_internal.SynchronousMeasurementConsumer"
+    )
     def test_consume_measurement_up_down_counter(
         self, mock_sync_measurement_consumer
     ):
@@ -293,7 +318,9 @@ class TestMeterProvider(ConcurrencyTestBase):
 
         sync_consumer_instance.consume_measurement.assert_called()
 
-    @patch("opentelemetry.sdk._metrics.SynchronousMeasurementConsumer")
+    @patch(
+        "opentelemetry.sdk.metrics._internal." "SynchronousMeasurementConsumer"
+    )
     def test_consume_measurement_histogram(
         self, mock_sync_measurement_consumer
     ):
@@ -400,3 +427,98 @@ class TestMeter(TestCase):
             observable_up_down_counter, ObservableUpDownCounter
         )
         self.assertEqual(observable_up_down_counter.name, "name")
+
+
+class InMemoryMetricExporter(MetricExporter):
+    def __init__(self):
+        super().__init__()
+        self.metrics = {}
+        self._counter = 0
+
+    def export(
+        self,
+        metrics: Sequence[Metric],
+        timeout_millis: float = 10_000,
+        **kwargs,
+    ) -> MetricExportResult:
+        self.metrics[self._counter] = metrics
+        self._counter += 1
+        return MetricExportResult.SUCCESS
+
+    def shutdown(self, timeout_millis: float = 30_000, **kwargs) -> None:
+        pass
+
+    def force_flush(self, timeout_millis: float = 10_000) -> bool:
+        return True
+
+
+class TestDuplicateInstrumentAggregateData(TestCase):
+    def test_duplicate_instrument_aggregate_data(self):
+
+        exporter = InMemoryMetricExporter()
+        reader = PeriodicExportingMetricReader(
+            exporter, export_interval_millis=500
+        )
+        view = View(
+            instrument_type=Counter,
+            attribute_keys=[],
+            aggregation=SumAggregation(),
+        )
+        provider = MeterProvider(
+            metric_readers=[reader],
+            resource=Resource.create(),
+            views=[view],
+        )
+
+        meter_0 = provider.get_meter(
+            name="meter_0",
+            version="version",
+            schema_url="schema_url",
+        )
+        meter_1 = provider.get_meter(
+            name="meter_1",
+            version="version",
+            schema_url="schema_url",
+        )
+        counter_0_0 = meter_0.create_counter(
+            "counter", unit="unit", description="description"
+        )
+        counter_0_1 = meter_0.create_counter(
+            "counter", unit="unit", description="description"
+        )
+        counter_1_0 = meter_1.create_counter(
+            "counter", unit="unit", description="description"
+        )
+
+        self.assertIs(counter_0_0, counter_0_1)
+        self.assertIsNot(counter_0_0, counter_1_0)
+
+        counter_0_0.add(1, {})
+        counter_0_1.add(2, {})
+
+        counter_1_0.add(7, {})
+
+        sleep(1)
+
+        reader.shutdown()
+
+        sleep(1)
+
+        metrics = exporter.metrics[0]
+
+        scope_metrics = metrics.resource_metrics[0].scope_metrics
+        self.assertEqual(len(scope_metrics), 2)
+
+        metric_0 = scope_metrics[0].metrics[0]
+
+        self.assertEqual(metric_0.name, "counter")
+        self.assertEqual(metric_0.unit, "unit")
+        self.assertEqual(metric_0.description, "description")
+        self.assertEqual(next(metric_0.data.data_points).value, 3)
+
+        metric_1 = scope_metrics[1].metrics[0]
+
+        self.assertEqual(metric_1.name, "counter")
+        self.assertEqual(metric_1.unit, "unit")
+        self.assertEqual(metric_1.description, "description")
+        self.assertEqual(next(metric_1.data.data_points).value, 7)
